@@ -4,24 +4,24 @@ TOTAL_STATISTICS = c("u_cases", "w_cases", "u_responses", "w_responses", "u_cpct
 #' Cross tabulation with support of labels, weights and multiple response variables.
 #' 
 #' \itemize{
-#' \item{\code{cross_cases}}{ build a contingency table of the counts.}
-#' \item{\code{cross_cpct}, \code{cross_cpct_responses}}{ build a contingency table 
+#' \item \code{cross_cases} build a contingency table of the counts.
+#' \item \code{cross_cpct}, \code{cross_cpct_responses} build a contingency table 
 #' of the column percent. These functions give different results only for 
 #' multiple response variables. For \code{cross_cpct} base of percent is number 
 #' of valid cases. Case is considered as valid if it has at least one non-NA 
 #' value. So for multiple response variables sum of percent may be greater than
 #' 100. For \code{cross_cpct_responses} base of percent is number of valid 
 #' responses. Multiple response variables can have several responses for single 
-#' case. Sum of percent of \code{cross_cpct_responses} always equals to 100\%.}
-#' \item{\code{cross_rpct}}{ build a contingency table of the row percent. Base
-#' for percent is number of valid cases.}
-#' \item{\code{cross_tpct}}{ build a contingency table of the table percent. Base
-#' for percent is number of valid cases.}
-#' \item{\code{cross_*}}{ functions evaluate their arguments
-#' in the context of the first argument \code{data}.}
-#' \item{\code{cro_*}}{ functions use standard evaluation, e. g 'cro(mtcars$am, mtcars$vs)'.}
-#' \item{\code{total}}{ auxiliary function - creates variables with 1 for valid
-#' case of its argument \code{x} and NA in opposite case.}
+#' case. Sum of percent of \code{cross_cpct_responses} always equals to 100\%.
+#' \item \code{cross_rpct} build a contingency table of the row percent. Base
+#' for percent is number of valid cases.
+#' \item \code{cross_tpct} build a contingency table of the table percent. Base
+#' for percent is number of valid cases.
+#' \item \code{cross_*} functions evaluate their arguments
+#' in the context of the first argument \code{data}.
+#' \item \code{cro_*} functions use standard evaluation, e. g 'cro(mtcars$am, mtcars$vs)'.
+#' \item \code{total} auxiliary function - creates variables with 1 for valid
+#' case of its argument \code{x} and NA in opposite case.
 #' }
 #' You can combine tables with \link{add_rows} and \link{merge.etable}. For
 #' sorting table see \link{tab_sort_asc}. 
@@ -714,7 +714,7 @@ margin_from_cases = function(cases, margin = c("columns", "rows", "total")){
                     rows =  "cell_var",
                     total =  NULL
     )
-    by_str = paste(c(row_var_name, margin), collapse = ",")    
+    by_str = c(row_var_name, margin)
     dtotal = cases[, list(total = sum(value, na.rm = TRUE)), by = by_str]
     dtotal
 }
@@ -792,7 +792,7 @@ calculate_response_column_margin = function(raw_data,
     value = NULL
     if(stat_type=="cpct_responses" || any(total_statistic %in% c("u_responses", "w_responses"))){  
         if(has_row_var(raw_data)){
-            by_str = "row_var,col_var"
+            by_str = c("row_var", "col_var")
         } else {
             by_str = "col_var"
         }
@@ -875,7 +875,7 @@ rbindlist_and_aggregate = function(list_of_datatables){
        list_of_datatables = unlist(list_of_datatables, recursive = FALSE, use.names = FALSE)    
     }
     res = rbindlist(list_of_datatables, use.names = FALSE, fill = FALSE)
-    by_str = paste(colnames(res)[!(colnames(res) %in% "value")], collapse = ",")
+    by_str = setdiff(colnames(res), "value")
     res[, list(value = sum(value, na.rm = TRUE)), by = by_str]
      
 }
@@ -897,7 +897,7 @@ internal_cases = function(raw_data, col_var_names, cell_var_names = NULL, use_we
     if(is.null(col_var_names)) col_var_names = list(NULL) 
     res = lapply(cell_var_names, function(each_cell) { 
         res = lapply(col_var_names, function(each_col){
-            by_str = paste(c(row_var_name, each_cell, each_col), collapse = ",")
+            by_str = c(row_var_name, each_cell, each_col)
             if(use_weight){
                 dres = raw_data[, list(value = sum(weight, na.rm = TRUE)), 
                                 by = by_str] 
