@@ -21,7 +21,7 @@ mtcars = apply_labels(mtcars,
 )
 
 mtcars_table = mtcars %>% 
-    calc_cro_cpct(
+    cross_cpct(
         cell_vars = list(cyl, gear),
         col_vars = list(total(), am, vs)
     ) %>% 
@@ -36,11 +36,11 @@ sh = addWorksheet(wb, "Tables")
 ## -----------------------------------------------------------------------------
 xl_write(mtcars_table, wb, sh)
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  saveWorkbook(wb, "table1.xlsx", overwrite = TRUE)
+## ----eval=FALSE---------------------------------------------------------------
+# saveWorkbook(wb, "table1.xlsx", overwrite = TRUE)
 
 ## -----------------------------------------------------------------------------
-banner = calc(mtcars, list(total(), am, vs))
+banner = with(mtcars, list(total(), am, vs))
 
 ## -----------------------------------------------------------------------------
 list_of_tables = lapply(mtcars, function(variable) {
@@ -68,6 +68,6 @@ xl_write(list_of_tables, wb, sh,
          other_cols_formats = list("#" = createStyle(textDecoration = "bold")),
          )
 
-## ---- eval = FALSE------------------------------------------------------------
-#  saveWorkbook(wb, "report.xlsx", overwrite = TRUE)
+## ----eval = FALSE-------------------------------------------------------------
+# saveWorkbook(wb, "report.xlsx", overwrite = TRUE)
 
