@@ -41,7 +41,7 @@ a = matrix(1:9, 3)
 
 expect_identical(uniq_elements(a), 1:9)
 
-a = list(1:3, a, dtfrm(5:6))
+a = list(1:3, a, sheet(5:6))
 expect_identical(uniq_elements(a), 1:9)
 
 ## just for coverage
